@@ -1,3 +1,3 @@
 from webXtools.bf import bruteforce, bruteforceList, bruteforceFile
 from webXtools.race import race
-from webXtools.jwthax import jwtBrute
\ No newline at end of file
+from webXtools.jwthax import jwtHS256Brute, jwtRS256Convert
\ No newline at end of file
